0.1.5
=====

* Allow arbitrary objects as context for templates.



0.1.4
=====

* Fix a bug in the app directories template loader where the path names were
  calling ``decode`` in Python 2 *and* 3.



0.1.3
=====

* Change the installation details

  Pip 1.5 makes it difficult to specify installation sources outside of the
  PyPI. Also, this is better motivation to get these packages officially on
  PyPI.



0.1.2
=====

* Depend on specific forks of pymeta and pybars



0.1.1
=====

* First Release